==> plugin.video.intergalacticfm-0.0.3.zip: plugin.video.intergalacticfm/README.md <==
Intergalactic FM TV Kodi Video Plugin
=====================================


![Intergalactic FM TV icon](icon.png?raw=true)


Installation
------------

Currently, installation is only possible by downloading ZIP file of this add-on on your system that runs Kodi and install it via the Kodi GUI.

  1. Download the ZIP file of this add-on with `wget https://github.com/PanderMusubi/plugin.video.intergalacticfm/archive/master.zip` somewhere on your system that runs Kodi. Alternatively, you can download it in another way and copy it to your system running Kodi.
  2. In the Kodi GUI, go to `Add-ons` and choose `Install from zip file`. Then select the downloaded file `master.zip` and this add-on will be installed.
  3. If the add-on is not directly available, a restart of Kodi might be in place.

In the near future, this add-on will be a default add-on that can be installed directly from Kodi. That will be announced at http://kodi.wiki/view/Add-on:Intergalactic\_FM\_TV when it is included in the standard repostory of Kodi.


![Intergalactic FM TV fanart](fanart.jpg?raw=true)


See also
--------

See also the audio plugin called Intergalactic FM at http://kodi.wiki/view/Add-on:Intergalactic_FM and https://github.com/PanderMusubi/plugin.audio.intergalacticfm


Thanks
------

Thanks go to the authors of the original add-on that was developed for My Jam TV and forked from https://github.com/myjamtv/kodi

Credits go to [Yulia Vilenksy](http://yuliavilensky.com) for persmission to use her photograph used as fanart.

Last but not least, thank you I-f and others for creating [Intergalactic FM](https://intergalacticfm.com) and embracing new initiatives and technologies to keep us all in musical orbit.

==> plugin.video.intergalacticfm-0.0.4.zip: plugin.video.intergalacticfm/README.md <==
Intergalactic FM TV Kodi Video Plugin
=====================================


![Intergalactic FM TV icon](icon.png?raw=true)


Installation
------------

Currently, installation is only possible by downloading ZIP file of this add-on on your system that runs Kodi and install it via the Kodi GUI.

  1. Download the ZIP file of this add-on with `wget https://github.com/PanderMusubi/plugin.video.intergalacticfm/archive/master.zip` somewhere on your system that runs Kodi. Alternatively, you can download it in another way and copy it to your system running Kodi.
  2. In the Kodi GUI, go to `Add-ons` and choose `Install from zip file`. Then select the downloaded file `master.zip` and this add-on will be installed.
  3. If the add-on is not directly available, a restart of Kodi might be in place.

In the near future, this add-on will be a default add-on that can be installed directly from Kodi. That will be announced at http://kodi.wiki/view/Add-on:Intergalactic_FM_TV when it is included in the standard repostory of Kodi.


![Intergalactic FM TV fanart](fanart.jpg?raw=true)


See also
--------

See also the audio plugin called Intergalactic FM at http://kodi.wiki/view/Add-on:Intergalactic_FM and https://github.com/PanderMusubi/plugin.audio.intergalacticfm


Thanks
------

Thanks go to the authors of the original add-on that was developed for My Jam TV and forked from https://github.com/myjamtv/kodi

Credits go to [Yulia Vilenksy](http://yuliavilensky.com) for persmission to use her photograph used as fanart.

Last but not least, thank you I-f and others for creating [Intergalactic FM](http://intergalacticfm.com) and embracing new initiatives and technologies to keep us all in musical orbit.
